@@ -10,18 +10,22 @@ from gv_utils.logger import Logger
 
 
 class Requests:
-    gvapiurl = 'http://gtlville-interface.inrialpes.fr/api'
 
     def __init__(self, logger: Logger) -> None:
         self.logger = logger
+        self.apiurl = None
+        self.session = None
+
+    async def async_init(self, apiaddr):
+        self.apiurl = 'http://{}/api'.format(apiaddr)
         self.session = aiohttp.ClientSession()
 
     async def get_data_point(self, datapointeids: list = None, datatypeeids: list = None,
                              area: BaseGeometry = None) -> dict:
         params = {}
         if datatypeeids is not None:
-            params[RequestParam.datatypeeid] = datatypeeids  # TODO: is encoding necessary?
-        return await self._get_location(datapointeids, area, RequestPath.road, params)
+            params[RequestParam.datatype] = self.__encode_list_params(datatypeeids)
+        return await self._get_location(datapointeids, area, RequestPath.datapoint, params)
 
     async def get_road(self, roadeids: list = None, area: BaseGeometry = None) -> dict:
         return await self._get_location(roadeids, area, RequestPath.road)
@@ -34,22 +38,22 @@ class Requests:
             params = {}
 
         if eids is not None:
-            params[RequestParam.eid] = eids  # TODO: is encoding necessary?
+            params[RequestParam.eid] = self.__encode_list_params(eids)
         if area is not None:
-            params[RequestParam.area] = encode_geometry(area)
+            params[RequestParam.within] = encode_geometry(area)
         return await self._get('{}/{}'.format(RequestPath.location, applyto), params)
 
     async def get_road_data_point(self, area: BaseGeometry = None) -> dict:
         params = {}
         if area is not None:
-            params[RequestParam.area] = encode_geometry(area)
+            params[RequestParam.within] = encode_geometry(area)
         return await self._get('{}/{}/{}'.format(RequestPath.mapping, RequestPath.road, RequestPath.datapoint), params)
 
     async def get_data_point_data_quality(self, period: str, fromdatetime: datetime, datapointeids: list = None,
                                           datatypeeids: list = None, todatetime: datetime = None) -> dict:
         params = {}
         if datatypeeids is not None:
-            params[RequestParam.datatypeeid] = datatypeeids  # TODO: is encoding necessary?
+            params[RequestParam.datatype] = self.__encode_list_params(datatypeeids)
         return await self._get_data_quality(period, fromdatetime, datapointeids, todatetime, RequestPath.datapoint,
                                             params)
 
@@ -71,7 +75,7 @@ class Requests:
                                        todatetime: datetime = None) -> dict:
         params = {}
         if datatypeeids is not None:
-            params[RequestParam.datatypeeid] = datatypeeids  # TODO: is encoding necessary?
+            params[RequestParam.datatype] = self.__encode_list_params(datatypeeids)
         return await self._get_indicator(indicator, period, fromdatetime, datapointeids, todatetime,
                                          RequestPath.datapoint, params)
 
@@ -80,7 +84,7 @@ class Requests:
                                                todatetime: datetime = None) -> dict:
         params = {}
         if datatypeeids is not None:
-            params[RequestParam.datatypeeid] = datatypeeids  # TODO: is encoding necessary?
+            params[RequestParam.datatype] = self.__encode_list_params(datatypeeids)
         return await self._get_indicator(indicator, period, fromdatetime, datapointeids, todatetime,
                                          '{}/{}'.format(RequestPath.imputed, RequestPath.datapoint), params)
 
@@ -105,7 +109,7 @@ class Requests:
         params[RequestParam.period] = period
         params[RequestParam.fromdatetime] = to_str(fromdatetime)
         if locationeids is not None:
-            params[RequestParam.eid] = locationeids  # TODO: is encoding necessary?
+            params[RequestParam.eid] = self.__encode_list_params(locationeids)
         if todatetime is not None:
             params[RequestParam.todatetime] = to_str(todatetime)
         return await self._get(applyto, params)
@@ -113,8 +117,8 @@ class Requests:
     async def get_zone_travel_time(self, frompointeid: str, topointeid: str, period: str, fromdatetime: datetime,
                                    todatetime: datetime = None) -> dict:
         params = {
-            RequestParam.frompointeid: frompointeid,
-            RequestParam.topointeid: topointeid,
+            RequestParam.frompoint: frompointeid,
+            RequestParam.topoint: topointeid,
             RequestParam.period: period,
             RequestParam.fromdatetime: to_str(fromdatetime)
         }
@@ -124,10 +128,15 @@ class Requests:
 
     async def _get(self, suffix: str, params: dict = None) -> dict:
         message = {}
-        async with self.session.get('{}/{}'.format(self.gvapiurl, suffix), params=params) as resp:
-            if resp.status == 200:
-                message = await parser.decode_message(await resp.text())
+        async with self.session as session:
+            async with session.get('{}/{}/'.format(self.apiurl, suffix), params=params) as resp:
+                if resp.status == 200:
+                    message = await parser.decode_message(await resp.text())
         return message
 
+    @staticmethod
+    def __encode_list_params(params: list) -> str:
+        return RequestParam.separator.join(params)
+
     async def close(self) -> None:
         await self.session.close()
