@@ -3,22 +3,31 @@
 
 class DbColumn:
     att = 'att'
+    classification = 'classification'
+    confidence = 'confidence'
     datapoint = 'data_point'
     datatype = 'data_type'
     dataquality = 'data_quality'
     day = 'day'
+    density = 'density'
     eid = 'eid'
+    flow = 'flow'
+    fluidity = 'fluidity'
     fromtraveltime = 'from_travel_time'
     fromzonepoint = 'from_zone_point'
+    geom = 'geom'
     id = 'id'
     imputedindicator = 'imputed_indicator'
     indicator = 'indicator'
     networkdataquality = 'network_data_quality'
     networkindicator = 'network_indicator'
+    occupancy = 'occupancy'
     road = 'road'
     sampletime = 'sample_time'
+    speed = 'speed'
     totraveltime = 'to_travel_time'
     tozonepoint = 'to_zone_point'
+    traveltime = 'travel_time'
     validfrom = 'valid_from'
     validto = 'valid_to'
     webatt = 'web_att'
@@ -47,18 +56,11 @@ class Message:
     kind = 'kind'
 
 
-class MessageData:
+class MessageData(DbColumn):
     csvseparator = ';'
     encoding = 'utf-8'
 
-    confidence = 'confidence'
-    density = 'density'
-    flow = 'flow'
-    fluidity = 'fluidity'
-    occupancy = 'occupancy'
-    speed = 'speed'
     status = 'status'
-    traveltime = 'traveltime'
 
     late = -2
     nan = -1
@@ -85,7 +87,7 @@ class AttId(DbColumn):
 
 class MessageFormat:
     json = 'json'
-    pandas = 'pandas'
+    csv = 'csv'
 
 
 class MessageKind:
@@ -112,17 +114,19 @@ class MessageKind:
 
 
 class RequestParam:
-    separator = ';'
+    separator = ','
 
-    area = 'area'
-    datatypeeid = 'datatypeeid'
+    internalflag = 'internal'
+
+    datatype = 'datatype'
     eid = 'eid'
     fromdatetime = 'fromdatetime'
-    frompointeid = 'frompointeid'
+    frompoint = 'frompoint'
     indicator = 'indicator'
     period = 'period'
-    topointeid = 'topointeid'
+    topoint = 'topoint'
     todatetime = 'todatetime'
+    within = 'within'
 
     day = 'day'
     week = 'week'
