@@ -131,11 +131,16 @@ def _get_range(i: int, radius: int) -> List[int]:
 
 
 def encode_geometry(geometry: BaseGeometry) -> str:
-    if not hasattr(geometry, '__geo_interface__'):
-        raise TypeError('{g} does not conform to '
-                        'the geo interface'.format(g=geometry))
     return '{};{}'.format('SRID={}'.format(SRID), shapely.wkt.dumps(geometry))
 
 
 def decode_geometry(wkt: str) -> BaseGeometry:
-    return shapely.wkt.loads(wkt.split(';')[-1])
+    geom = None
+    try:
+        geom = shapely.wkt.loads(wkt.split(';')[-1])
+    except:
+        try:
+            geom = shapely.geometry.shape(wkt)
+        except:
+            pass
+    return geom
